@@ -1,40 +1,41 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: cpumeter.cc,v 1.2 1996/08/14 06:20:55 mromberg Exp $
+//
 #include "cpumeter.h"
 #include "xosview.h"
 #include <fstream.h>
+#include <stdlib.h>
 
 
 static const char STATFILENAME[] = "/proc/stat";
 
 
-CPUMeter::CPUMeter( XOSView *parent, int x, int y, int width, int height )
-: FieldMeter( parent, x, y, width, height, 4, "CPU", "USR/NICE/SYS/FREE" ){
+CPUMeter::CPUMeter( XOSView *parent )
+: FieldMeterDecay( parent, 4, "CPU", "USR/NICE/SYS/FREE" ){
   for ( int i = 0 ; i < 2 ; i++ )
     for ( int j = 0 ; j < 4 ; j++ )
       cputime_[i][j] = 0;
   cpuindex_ = 0;
 
-  parent_->addResource( "cpuUserColor", NULL, "blue" );
-  parent_->addResource( "cpuNiceColor", NULL, "yellow" );
-  parent_->addResource( "cpuSystemColor", NULL, "red" );
-  parent_->addResource( "cpuFreeColor", NULL, "green2" );
 }
 
 CPUMeter::~CPUMeter( void ){
 }
 
 void CPUMeter::checkResources( void ){
-  FieldMeter::checkResources();
+  FieldMeterDecay::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "cpuUserColor" ) );
   setfieldcolor( 1, parent_->getResource( "cpuNiceColor" ) );
   setfieldcolor( 2, parent_->getResource( "cpuSystemColor" ) );
   setfieldcolor( 3, parent_->getResource( "cpuFreeColor" ) );
+  priority_ = atoi (parent_->getResource( "cpuPriority" ) );
+  dodecay_ = !strcmp (parent_->getResource( "cpuDecay" ), "True" );
 }
 
 void CPUMeter::checkevent( void ){
@@ -63,7 +64,8 @@ void CPUMeter::getcputime( void ){
     total_ += fields_[i];
   }
 
-  used( (int)((100 * (total_ - fields_[3])) / total_) );
-
-  cpuindex_ = (cpuindex_ + 1) % 2;
+  if (total_){
+    used( (int)((100 * (total_ - fields_[3])) / total_) );
+    cpuindex_ = (cpuindex_ + 1) % 2;
+  }
 }
