@@ -1,20 +1,22 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: cpumeter.h,v 1.2 1996/08/14 06:20:57 mromberg Exp $
+//
 #ifndef _CPUMETER_H_
 #define _CPUMETER_H_
 
-#include "fieldmeter.h"
+#include "fieldmeterdecay.h"
 
-class CPUMeter : public FieldMeter {
+class CPUMeter : public FieldMeterDecay {
 public:
-  CPUMeter( XOSView *parent, int x, int y, int width, int height );
+  CPUMeter( XOSView *parent );
   ~CPUMeter( void );
 
-  const char *name( void ) { return "CPUMeter"; }
+  const char *name( void ) const { return "CPUMeter"; }
   void checkevent( void );
 
   void checkResources( void );
