@@ -1,27 +1,27 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: intmeter.cc,v 1.4 1997/10/28 16:55:25 romberg Exp $
+//
 #include "intmeter.h"
 #include "xosview.h"
 #include <fstream.h>
+#include <stdlib.h>
 
 
 static const char *INTFILE = "/proc/interrupts";
 
 
-IntMeter::IntMeter( XOSView *parent, int x, int y, int width, int height, 
-		   const char *title, const char *legend, int dolegends,
-		   int dousedlegends )
-: BitMeter( parent, x, y, width, height, "INTS", "IRQs (0 - 15)", 16, 
-	    dolegends, dousedlegends ) {
+IntMeter::IntMeter( XOSView *parent,
+                    const char *, const char *, int dolegends,
+                    int dousedlegends )
+  : BitMeter( parent, "INTS", "IRQs (0 - 15)", 16, 
+              dolegends, dousedlegends ) {
   for ( int i = 0 ; i < 16 ; i++ )
     irqs_[i] = lastirqs_[i] = 0;
-
-  parent_->addResource( "intOnColor", NULL, "red" );
-  parent_->addResource( "intOffColor", NULL, "blue" );
 }
 
 IntMeter::~IntMeter( void ){
@@ -47,32 +47,34 @@ void IntMeter::checkResources( void ){
 void IntMeter::getirqs( void ){
   ifstream intfile( INTFILE );
   int intno, count;
-  char buf[256];
 
   if ( !intfile ){
     cerr <<"Can not open file : " <<INTFILE <<endl;
     exit( 1 );
- }
+  }
 
- while ( !intfile.eof() ){
-    intfile >>intno >>buf;;
+  while ( !intfile.eof() ){
+    intfile >>intno;
+    if (!intfile) break;
+    intfile.ignore(1);
     if ( !intfile.eof() ){
       intfile >>count;
-     intfile.getline( buf, 256 );
-
+      intfile.istream::ignore(1024, '\n');
+      
       irqs_[intno] = count;
     }
   }
 
-//  ifstream intfile( INTFILE );
-//  char buf[256];
-//
-//  for ( int i = 0 ; i < 4 ; i++ )
-//    intfile.getline( buf, 256 );
-//
-//  intfile >>buf;
-//  
-//  for ( i = 0 ; i < 16 ; i++ )
-//    intfile >>irqs_[i];
-
+#if 0
+  while ( !intfile.eof() ){
+    intfile >>intno;
+    intfile.ignore(1);
+    if ( !intfile.eof() ){
+      intfile >>count;
+      intfile.istream::ignore(1024, '\n');
+      
+      irqs_[intno] = count;
+    }
+  }
+#endif
 }
