@@ -1,18 +1,19 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: intmeter.h,v 1.3 1996/12/26 20:18:57 mromberg Exp $
+//
 #ifndef _INTMETER_H_
 #define _INTMETER_H_
 
 #include "bitmeter.h"
 
-
 class IntMeter : public BitMeter {
 public:
-  IntMeter( XOSView *parent, int x, int y, int width, int height, 
+  IntMeter( XOSView *parent,
 	    const char *title = "", const char *legend ="",
 	    int dolegends = 0, int dousedlegends = 0 );
   ~IntMeter( void );
