@@ -1,12 +1,17 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
+//
+// $Id: swapmeter.cc,v 1.3 1997/10/04 02:16:33 mromberg Exp $
+//
 
 #include "swapmeter.h"
 #include "xosview.h"
 #include <fstream.h>
+#include <strstream.h>
+#include <stdlib.h>
 
 #ifdef USESYSCALLS
 #include <syscall.h>
@@ -17,22 +22,21 @@
 static const char MEMFILENAME[] = "/proc/meminfo";
 
 
-SwapMeter::SwapMeter( XOSView *parent, int x, int y, int width, int height )
-: FieldMeter( parent, x, y, width, height, 2, "SWAP", "USED/FREE" ){
-  parent_->addResource( "swapUsedColor", NULL, "blue" );
-  parent_->addResource( "swapFreeColor", NULL, "green2" );
+SwapMeter::SwapMeter( XOSView *parent )
+: FieldMeterDecay( parent, 2, "SWAP", "USED/FREE" ){
   
-  priority_ = 10;
 }
 
 SwapMeter::~SwapMeter( void ){
 }
 
 void SwapMeter::checkResources( void ){
-  FieldMeter::checkResources();
+  FieldMeterDecay::checkResources();
 
   setfieldcolor( 0, parent_->getResource( "swapUsedColor" ) );
   setfieldcolor( 1, parent_->getResource( "swapFreeColor" ) );
+  priority_ = atoi (parent_->getResource( "swapPriority" ) );
+  dodecay_ = !strcmp (parent_->getResource( "swapDecay" ), "True" );
 }
 
 void SwapMeter::checkevent( void ){
@@ -56,22 +60,36 @@ void SwapMeter::getswapinfo( void ){
     fields_[0] = 0;
     fields_[1] = 1;
   }
-
-  used( (int)((100 * fields_[0]) / total_ ) );
+  
+  if (total_)
+    used( (int)((100 * fields_[0]) / total_ ) );
 }
 #else
 void SwapMeter::getswapinfo( void ){
-  char buf[256];  
   ifstream meminfo( MEMFILENAME );
-
   if ( !meminfo ){
     cerr <<"Con not open file : " <<MEMFILENAME <<endl;
     exit( 1 );
   }
 
-  meminfo.getline( buf, 256 );
-  meminfo.getline( buf, 256 );  
-  meminfo >>buf >>total_ >>fields_[0] >>fields_[1];
+  total_ = fields_[0] = fields_[1] = 0;
+
+  char buf[256];
+  char ignore[256];
+
+  // Get the info from the "standard" meminfo file.
+  while (!meminfo.eof()){
+    meminfo.getline(buf, 256);
+    istrstream line(buf, 256);
+
+    if(!strncmp("SwapTotal", buf, strlen("SwapTotal")))
+        line >> ignore >> total_;
+
+    if(!strncmp("SwapFree", buf, strlen("SwapFree")))
+        line >> ignore >> fields_[1];
+  }
+  
+  fields_[0] = total_ - fields_[1];
 
   if ( total_ == 0 ){
     total_ = 1;
@@ -79,7 +97,8 @@ void SwapMeter::getswapinfo( void ){
     fields_[1] = 1;
   }
 
-  used( (int)((100 * fields_[0]) / total_ ) );
+  if (total_)
+    used( (int)((100 * fields_[0]) / total_ ) );
 }
 #endif
 
