@@ -1,15 +1,20 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: meter.cc,v 1.3 1996/11/19 04:14:53 bgrayson Exp $
+//
+#include "general.h"
 #include "meter.h"
 #include "xosview.h"
 
-Meter::Meter( XOSView *parent, int x, int y, int width, int height, 
-	      const char *title, const char *legend, int dolegends,
-	      int dousedlegends ) {
+CVSID("$Id: meter.cc,v 1.3 1996/11/19 04:14:53 bgrayson Exp $");
+CVSID_DOT_H(METER_H_CVSID);
+
+Meter::Meter( XOSView *parent, const char *title, const char *legend, 
+              int dolegends, int dousedlegends ) {
   title_ = legend_ = NULL;
   Meter::title( title );
   Meter::legend( legend );
@@ -18,10 +23,8 @@ Meter::Meter( XOSView *parent, int x, int y, int width, int height,
   dousedlegends_ = dousedlegends;
   priority_ = 1;
   counter_ = 0;
-  resize( x, y, width, height );
+  resize( parent->xoff(), parent->newypos(), parent->width() - 10, 10 );
 
-  if ( parent_->getResource( "meterLabel" ) == NULL )
-    parent_->addResource( "meterLabel", NULL, "yellow" );
 }
 
 Meter::~Meter( void ){
@@ -30,7 +33,7 @@ Meter::~Meter( void ){
 }
 
 void Meter::checkResources( void ){
-  textcolor_ = parent_->allocColor( parent_->getResource( "meterLabel" ) );
+  textcolor_ = parent_->allocColor( parent_->getResource( "meterLabelColor") );
 }
 
 void Meter::title( const char *title ){
