@@ -1,22 +1,27 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: meter.h,v 1.4 1997/01/14 18:23:27 bgrayson Exp $
+//
 #ifndef _METER_H_
 #define _METER_H_
 
+#define METER_H_CVSID "$Id: meter.h,v 1.4 1997/01/14 18:23:27 bgrayson Exp $"
+
+#include "xosview.h"	//  To grab MAX_SAMPLES_PER_SECOND.
+
 class XOSView;
 
 class Meter {
 public:
-  Meter( XOSView *parent, int x, int y, int width, int height, 
-	 const char *title = "", const char *legend ="", 
+  Meter( XOSView *parent, const char *title = "", const char *legend ="", 
 	 int dolegends = 0, int dousedlegends = 0 );
   virtual ~Meter( void );
 
-  virtual const char *name( void ) { return "Meter"; }
+  virtual const char *name( void ) const { return "Meter"; }
   void resize( int x, int y, int width, int height );
   virtual void checkevent( void ) = 0;
   virtual void draw( void ) = 0;
@@ -40,6 +45,8 @@ protected:
   int priority_, counter_;
   char *title_, *legend_;
   unsigned long textcolor_;
+  double samplesPerSecond() { return 1.0*MAX_SAMPLES_PER_SECOND/priority_; }
+  double secondsPerSample() { return 1.0/samplesPerSecond(); }
 
 private:
 };
