@@ -1,12 +1,16 @@
 //  
-//  Copyright (c) 1994 by Mike Romberg (  romberg@md.fsl.noaa.gov )
+//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-
+//
+// $Id: timer.h,v 1.4 1997/07/18 03:32:35 bgrayson Exp $
+//
 #ifndef _TIMER_H_
 #define _TIMER_H_
 
+#define TIMER_H_CVSID "$Id: timer.h,v 1.4 1997/07/18 03:32:35 bgrayson Exp $"
+
 //
 //                 General purpose interval timer class
 //
@@ -15,8 +19,7 @@
 //   Author : Mike Romberg
 
 
-#include <sys/time.h>
-
+#include "timeval.h"
 
 class Timer {
 public:
@@ -26,13 +29,26 @@ public:
   void start( void ) { gettimeofday( &starttime_, NULL ); }
   void stop( void )  { gettimeofday( &stoptime_, NULL );  }
   //  reports time intervall between calls to start and stop in usec
-  long report( void ) { 
-    return (stoptime_.tv_sec - starttime_.tv_sec) * 100000
+  long long report( void ) const { 
+    return (stoptime_.tv_sec - starttime_.tv_sec) * 1000000
            + stoptime_.tv_usec - starttime_.tv_usec; 
   }
+  
+  ostream &printOn(ostream &os) const {
+    return os <<"Timer : ["
+      <<"starttime_ = " <<TimeVal(starttime_)
+      <<", stoptime_ = " <<TimeVal(stoptime_)
+      <<", duration = " <<report() <<"]";
+  }
+
 protected:
   struct timeval starttime_, stoptime_;
+
 private:
 };
 
+inline ostream &operator<<(ostream &os, const Timer &t){
+  return t.printOn(os);
+}
+
 #endif
