@@ -1,42 +1,66 @@
-#include "xwin.h"
-#include <X11/Xresource.h>
+//
+// $Id: xwin.cc,v 1.8 1997/04/15 23:40:26 bgrayson Exp $
+//
+
+#include <X11/Xatom.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include "general.h"
+#include "xwin.h"
+#include "Xrm.h"
 
-static const char DEFAULT_BGCOLOR[] = "white";
-static const char DEFAULT_FGCOLOR[] = "black";
-static const char DEFAULT_FONT[]    = "fixed";
-static const int  DEFAULT_BDWIDTH   = 1;
-
+CVSID("$Id: xwin.cc,v 1.8 1997/04/15 23:40:26 bgrayson Exp $");
+CVSID_DOT_H(XWIN_H_CVSID);
 
 //-----------------------------------------------------------------------------
 
-XWin::XWin( int argc, char *argv[], char *geometry ){
-  width_ = height_ = x_ = y_ = 0;
-  preinit( argc, argv );
-  addResource( new Parm( "geometry", "-geometry", geometry ) );  
+//  argc is a reference, so that the changes to argc by XrmParseCommand are
+//  noticed by the caller (XOSView, in this case).  BCG
+XWin::XWin(){
 }
 //-----------------------------------------------------------------------------
 
 XWin::XWin( int argc, char *argv[], int x, int y, int width, int height ){
+  fprintf (stderr, "This constructor call is not supported!  (%s:%d)\n",
+    __FILE__, __LINE__);
+  exit (-1);
+  //  FIXME BCG  This constructor needs to do much of the work of the above
+  //  one.  Or, we need to drop this as a constructor.  As it is, it is
+  //  VERY MUCH out of date.
   x_ = x;
   y_ = y;
   width_ = width;
   height_ = height;
-  preinit( argc, argv );
-  addResource( new Parm( "geometry", "-geometry", NULL ) );    
+  (void) argc;
+  (void) argv;
 }
 //-----------------------------------------------------------------------------
 
+void XWin::XWinInit (int argc, char** argv, char* geometry, Xrm* xrm) {
+  (void) argc;
+  (void) argv;  //  Avoid gcc warnings about unused variables.
+  //  Eventually, we may want to have XWin handle some arguments other
+  //  than resources, so argc and argv are left as parameters.  BCG
+
+  geometry_ = geometry;  //  Save for later use.
+  width_ = height_ = x_ = y_ = 0;
+  xrmptr_ = xrm;
+
+  name_ = "";
+  font_ = NULL;
+  done_ = 0;  
+  
+  // Set up the default Events
+  events_ = NULL;
+  addEvent( new Event( this, ConfigureNotify, &configureEvent ) );
+  addEvent( new Event( this, ClientMessage, &deleteEvent ) );
+  addEvent( new Event( this, MappingNotify, &mappingNotify ) );
+
+  //openDisplay();  //  Done explicitly in xosview.cc.
+}
+
 XWin::~XWin( void ){
-  // delete the resources_
-  Parm *tmp = resources_;
-  while ( tmp != NULL ){
-    Parm *save = tmp->next_;
-    delete tmp;
-    tmp = save;
-  }
 
   // delete the events
   Event *event = events_;
@@ -46,7 +70,6 @@ XWin::~XWin( void ){
     event = save;
   }
   
-  // close the connection to the display
   XFree( title_.value );
   XFree( iconname_.value );
   XFree( sizehints_ );
@@ -55,40 +78,15 @@ XWin::~XWin( void ){
   XFreeGC( display_, gc_ );
   XFreeFont( display_, font_ );
   XDestroyWindow( display_, window_ );
+  // close the connection to the display
   XCloseDisplay( display_ );
 }
 //-----------------------------------------------------------------------------
 
-void XWin::preinit( int argc, char *argv[] ){
-  name_ = "";
-  done_ = 0;  
-  
-  // Set up the default resources
-  resources_ = NULL;
-  addResource( new Parm( "background", "-bg", (char *)DEFAULT_BGCOLOR ) );
-  addResource( new Parm( "foreground", "-fg", (char *)DEFAULT_FGCOLOR ) );
-  addResource( new Parm( "font", "-fn", (char *)DEFAULT_FONT ) );
-  addResource( new Parm( "display", "-d", NULL ) );
-
-  // Set up the default Events
-  events_ = NULL;
-  addEvent( new Event( this, ConfigureNotify, configureEvent ) );
-  addEvent( new Event( this, ClientMessage, deleteEvent ) );
-  addEvent( new Event( this, MappingNotify, mappingNotify ) );
-
-
-  openDisplay();
-  font_ = NULL;
-}
-//-----------------------------------------------------------------------------
-
 void XWin::init( int argc, char **argv ){
   XGCValues            gcv;
   XSetWindowAttributes xswa;
 
-  getResources();
-  parseArgs( argc, argv );  
-
   setFont();
   setColors();
   getGeometry();
@@ -96,7 +94,8 @@ void XWin::init( int argc, char **argv ){
   window_ = XCreateSimpleWindow(display_, DefaultRootWindow(display_), 
 				sizehints_->x, sizehints_->y,
 				sizehints_->width, sizehints_->height, 
-				DEFAULT_BDWIDTH, fgcolor_, bgcolor_);
+				1,
+				fgcolor_, bgcolor_);
 
   setHints( argc, argv );
 
@@ -127,6 +126,13 @@ void XWin::init( int argc, char **argv ){
     cerr <<"Error getting attributes of Main." <<endl;
     exit(2);
   }
+
+  //  Create stipple pixmaps.
+  stipples_[0] = createPixmap("\000\000", 2, 2);
+  stipples_[1] = createPixmap("\002\000\001\000", 2, 4);
+  stipples_[2] = createPixmap("\002\001", 2, 2);
+  stipples_[3] = createPixmap("\002\003\001\003", 2, 4);
+  doStippling_ = isResourceTrue("enableStipple");
 }
 //-----------------------------------------------------------------------------
 
@@ -134,10 +140,11 @@ void XWin::setFont( void ){
   // Set up the font
   if ( font_ != NULL )
     return;
+  const char* fontName = getResource("font");
 
-  if ((font_ = XLoadQueryFont(display_, getResource( "font" ))) == NULL){
+  if ((font_ = XLoadQueryFont(display_, fontName)) == NULL){
     cerr <<name_ <<": display " <<DisplayString(display_)
-      <<" cannot load font " <<getResource( "font" ) <<endl;
+      <<" cannot load font " << fontName << endl;
     exit(1);
   }
 }
@@ -149,8 +156,9 @@ void XWin::setHints( int argc, char *argv[] ){
     cerr <<"Error allocating class hint!" <<endl;
     exit(1);
   }
-  classhints_->res_name = name_;
-  classhints_->res_class = name_;
+  //  We have to cast away the const's.
+  classhints_->res_name = (char*) xrmptr_->instanceName();
+  classhints_->res_class = (char*) xrmptr_->className();
 
   // Set up the window manager hints
   if((wmhints_ = XAllocWMHints()) == NULL){
@@ -184,9 +192,8 @@ void XWin::setHints( int argc, char *argv[] ){
 
 void XWin::openDisplay( void ){
   // Open connection to display selected by user
-  if ((display_ = XOpenDisplay(getResource( "display" ))) == NULL) {
-    cerr <<"Can't open display named "
-	 <<XDisplayName(getResource( "display" )) <<endl;
+  if ((display_ = XOpenDisplay (display_name_)) == NULL) {
+    cerr <<"Can't open display named " << display_name_ <<endl;
     exit(1);
   }
 
@@ -194,94 +201,11 @@ void XWin::openDisplay( void ){
 }
 //-----------------------------------------------------------------------------
 
-void XWin::parseArgs( int argc, char *argv[] ){
-  int i = 1;
-
-  while ( i < argc ){
-    Parm *tmp = resources_;
-    while ( tmp != NULL ){
-      char buff[80] = "-";
-      strcat( buff, tmp->rname_ );
-      if ( !strcmp( buff, argv[i] ) || 
-	  ((tmp->oname_ != NULL) && (!strcmp( tmp->oname_, argv[i] ))) ){
-        if ( tmp->isBool_ )              // is a boolean Parm
-	  tmp->setBoolVal( 1 );
-	else {                           // is a value Parm
-	  if ( argc <= i + 1 )
-	    cerr <<"XWin::parseArgs() : no argument for " <<argv[i] <<endl;
-	  else {
-	    changeResource( tmp->rname_, argv[i+1] );
-	    i++;
-	  }
-	}
-	break;
-      }
-      tmp = tmp->next_;
-    }
-    i++;
-  }
-}
-//-----------------------------------------------------------------------------
-
-void XWin::getResources( void ){
-  char                 rfilename[80];
-  XrmDatabase          rdb;
-  char                 *type;
-  XrmValue             value;
-  char                 rname[80];
-
-  // Get resources from the resource file
-  XrmInitialize();
-#ifdef DEBIAN
-  *rfilename=0;
-#endif
-  if ( getenv( "HOME" ) != NULL ){
-    strcpy(rfilename, getenv("HOME"));
-    strcat(rfilename, "/.Xdefaults");
-  }
-#ifdef DEBIAN
-  int f; 
-  if (f=fopen(rfilename,"r"))
-    fclose(f);
-#endif
-  else
-    strcpy(rfilename, "/usr/lib/X11/app-defaults/XOSView" );
-
-  rdb = XrmGetFileDatabase(rfilename);
-  if(rdb != NULL){
-    Parm *tmp = resources_;
-    while( tmp != NULL ){
-      // Construct a complete resource name by appending the
-      // resource name to the application's name.      
-      strcpy( rname, name_ );
-      strcat( rname, "*" );
-      strcat( rname, tmp->rname_ );
-
-      if ( XrmGetResource( rdb, rname, rname, &type, &value ) ){
-	if ( tmp->isBool_ && (strcmp( value.addr, "True" ) && 
-			      strcmp( value.addr, "False" )) ){
-	  cerr <<"XWin::getResources() : " <<rname 
-	       <<" must be True or False" <<endl;
-	  value.addr = tmp->value_;
-	}
-	// memory leak!!!!!!!!!!!!!!!!!
-	tmp->value_ = new char[strlen( value.addr )+1];
-	strcpy( tmp->value_, value.addr );
-//	tmp->value_ = value.addr;
-      }
-
-      tmp = tmp->next_;
-    }
-  }
-  XrmDestroyDatabase( rdb );
-}
-//-----------------------------------------------------------------------------
-
 void XWin::setColors( void ){
   XColor               color;  
   
   // Main window's background color
-  if (XParseColor(display_, colormap_, getResource( "background" ),
+  if (XParseColor(display_, colormap_, getResource("background"),
 		  &color) == 0 ||
       XAllocColor(display_, colormap_, &color) == 0)
     bgcolor_ = WhitePixel(display_, DefaultScreen(display_));
@@ -289,7 +213,7 @@ void XWin::setColors( void ){
     bgcolor_ = color.pixel;
 
   // Main window's foreground color */
-  if (XParseColor(display_, colormap_, getResource( "foreground" ),
+  if (XParseColor(display_, colormap_, getResource("foreground"),
 		  &color) == 0 ||
       XAllocColor(display_, colormap_, &color) == 0)
     fgcolor_ = BlackPixel(display_, DefaultScreen(display_));
@@ -322,17 +246,24 @@ void XWin::getGeometry( void ){
 
   // Process the geometry specification
   bitmask =  XGeometry(display_, DefaultScreen(display_), 
-		       getResource( "geometry" ), default_geometry,
-		       DEFAULT_BDWIDTH, 
+		       getResourceOrUseDefault("geometry", geometry_), 
+                       default_geometry,
+		       0, 
 		       1, 1, 0, 0, &(sizehints_->x), &(sizehints_->y),
 		       &(sizehints_->width), &(sizehints_->height));
 
   // Check bitmask and set flags in XSizeHints structure
-  if (bitmask & (XValue | YValue)){
+  if (bitmask & (WidthValue | HeightValue)){
     sizehints_->flags |= PPosition;
     width_ = sizehints_->width;
     height_ = sizehints_->height;
   }
+
+  if (bitmask & (XValue | YValue)){
+    sizehints_->flags |= USPosition;
+    x_ = sizehints_->x;
+    y_ = sizehints_->y;
+  }
 }
 //-----------------------------------------------------------------------------
 
@@ -372,11 +303,14 @@ void XWin::checkevent( void ){
   }
 }
 //-----------------------------------------------------------------------------
-
+#if 0
 void XWin::usage( void ){
+  //  FIXME  We need to update this.  BCG
+#warning The usage() function needs to be updated.
   cerr <<name_ <<" [-display name] [-geometry geom]" <<endl;
 //    exit (1);
 }
+#endif
 //-----------------------------------------------------------------------------
 
 void XWin::addEvent( Event *event ){
@@ -392,50 +326,35 @@ void XWin::addEvent( Event *event ){
 }
 //-----------------------------------------------------------------------------
 
-const char *XWin::getResource( const char *name ){
-  Parm *tmp = resources_;
-  while ( tmp != NULL ) {
-    if ( !strcmp( name, tmp->rname_ ) )
-      return tmp->value_;
-    tmp = tmp->next_;
-  }
-  return NULL;
+const char *XWin::getResourceOrUseDefault( const char *name, const char* defaultVal ){
+
+  const char* retval = xrmptr_->getResource (name);
+  if (retval)
+    return retval;
+  else
+    return defaultVal;
 }
+
 //-----------------------------------------------------------------------------
 
-void XWin::changeResource( const char *name, char *value ){
-  Parm *tmp = resources_;
-  while ( tmp != NULL ) {
-    if ( !strcmp( name, tmp->rname_ ) ){
-      tmp->value_ = value;
-      return;
-    }
-    tmp = tmp->next_;
+const char *XWin::getResource( const char *name ){
+  const char* retval = xrmptr_->getResource (name);
+  if (retval)
+    return retval;
+  else
+  {
+    cerr << "Error:  Couldn't find '" << name << "' resource in the resource database!\n";
+    exit (-1);
+      /*  Some compilers aren't smart enough to know that exit() exits.  */
+    return '\0';
   }
 }
+
 //-----------------------------------------------------------------------------
 
 void XWin::dumpResources( ostream &os ){
-  os <<"------------- X resources -------------------" <<endl;
-
-  Parm *tmp = resources_;
-  while ( tmp != NULL ) {
-    os <<*tmp <<endl;
-    tmp = tmp->next_;
-  }
-}
-//-----------------------------------------------------------------------------
-
-void XWin::addResource( Parm *parm ){
-  Parm *tmp = resources_;
-
-  if ( resources_ == NULL )
-    resources_ = parm;
-  else {
-    while ( tmp->next_ != NULL )
-      tmp = tmp->next_;
-    tmp->next_ = parm;
-  }
+cerr << "Function not implemented!\n";  //  BCG  FIXME  Need to make this.
+(void) os;  //  Keep gcc happy.
 }
 //-----------------------------------------------------------------------------
 
@@ -459,7 +378,7 @@ void XWin::configureEvent( XEvent &event ){
 
 void XWin::deleteEvent( XEvent &event ){
   if ( (event.xclient.message_type == wm_ ) &&
-       (event.xclient.data.l[0] == wmdelete_) )
+       ((unsigned)event.xclient.data.l[0] == wmdelete_) )
     done( 1 );
 }
 //-----------------------------------------------------------------------------
