@@ -1,23 +1,29 @@
+//
+// $Id: xwin.h,v 1.4 1996/12/02 04:51:39 bgrayson Exp $
+//
 #ifndef _XWIN_H_
 #define _XWIN_H_
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include <X11/Xatom.h>
 #include <iostream.h>
 #include <string.h>
 
+#define XWIN_H_CVSID "$Id: xwin.h,v 1.4 1996/12/02 04:51:39 bgrayson Exp $"
 
 class XWin;
+class Xrm;
 
 typedef void (XWin::*EventCallBack)( XEvent &event );
 
 
 class XWin {
 public:
+  XWin ();
   XWin( int argc, char *argv[], int x, int y, int width, int height );
-  XWin( int argc, char *argv[], char *geometry );
+  //XWin( int& argc, char *argv[], char *geometry );
   virtual ~XWin( void );
+  void XWinInit ( int argc, char* argv[], char* geometry, Xrm* xrmp );
 
   int x( void ) { return x_; }
   void x( int val ) { x_ = val; }
@@ -42,6 +48,16 @@ public:
     { XSetForeground( display_, gc_, pixelvalue ); }
   void setBackground( unsigned long pixelvalue )
     { XSetBackground( display_, gc_, pixelvalue ); }
+  void setStipple( Pixmap stipple) 
+    { if (!doStippling_) return;
+      XSetStipple(display_, gc_, stipple);
+      XGCValues xgcv;
+      xgcv.fill_style = FillOpaqueStippled;
+      XChangeGC (display_, gc_, GCFillStyle, &xgcv); }
+  void setStippleN (int n) {setStipple(stipples_[n]); }
+  Pixmap createPixmap(char* data, unsigned int w, unsigned int h) {
+      return XCreatePixmapFromBitmapData(display_, window_, data, w, h,
+      0, 1, 1); }
   unsigned long foreground( void ) { return fgcolor_; }
   unsigned long background( void ) { return bgcolor_; }
   void resize( int width, int height ) 
@@ -57,7 +73,7 @@ public:
   void drawRectangle( int x, int y, int width, int height )
     { XDrawRectangle( display_, window_, gc_, x, y, width, height ); }
   void drawFilledRectangle( int x, int y, int width, int height )
-    { XFillRectangle( display_, window_, gc_, x, y, width, height ); }
+    { XFillRectangle( display_, window_, gc_, x, y, width + 1, height + 1 ); }
   void drawString( int x, int y, const char *str )
     { XDrawString( display_, window_, gc_, x, y, str, strlen( str ) ); }
   int textWidth( const char *str, int n )
@@ -74,9 +90,10 @@ public:
   void unmap( void ) { XUnmapWindow( display_, window_ ); }
   void flush( void ) { XFlush( display_ ); }
 
-  void addResource( char *rname, char *oname, char *value, int isBool = 0 )
-    {  addResource( new Parm( rname, oname, value, isBool ) ); }
   const char *getResource( const char *name );
+  const char *getResourceOrUseDefault( const char *name, const char* defaultVal );
+  const int isResourceTrue( const char* name ) {
+    return (!strcasecmp(getResource(name),"True")); }
   void dumpResources( ostream &os );
   
 protected:
@@ -99,35 +116,6 @@ protected:
     Event *next_;
   };
 
-
-
-  class Parm {
-  public:
-    Parm( void )
-      { rname_ = oname_ = value_ = NULL; isBool_ = 0; }
-    Parm( char *rname, char *oname, char *value, int isBool = 0 ){ 
-      rname_ = rname; oname_ = oname; value_ = value; 
-      next_ = NULL; isBool_ = isBool; 
-    }
-
-    friend ostream &operator<<( ostream &os, Parm &parm ){
-      return os <<"resource : " <<parm.rname_
-	        <<", opt   : "  <<parm.oname_
-		<<", value : "  <<parm.value_
-		<<", isBool : " <<parm.isBool_;
-    }
-    void setBoolVal( int val ) { 
-      if ( val ) 
-        value_ = "True";  
-      else 
-        value_ = "False"; 
-    }
-	 
-    char *rname_, *oname_, *value_;
-    int isBool_;
-    Parm *next_;
-  };
-  
   int x_, y_;                   //  position of the window
   int width_, height_;          //  width and height of the window
   Display       *display_;      //  Connection to X display
@@ -143,19 +131,21 @@ protected:
   XWMHints      *wmhints_;      //  Hints for the window manager
   XSizeHints    *sizehints_;    //  Size hints for window manager
   XClassHint    *classhints_;   //  Class hint for window manager
-  Parm          *resources_;    //  List of user-customizable resources
   Event         *events_;       //  List of Events for this window
   int           done_;          //  If true the application is finished.
   Atom          wm_, wmdelete_; //  Used to handle delete Events
   Colormap      colormap_;      //  The colormap
+  char		display_name_[256];  //  Display name string.
+  char*		geometry_;	//  geometry string.
+  Xrm*		xrmptr_;	//  Pointer to the XOSView xrm.  FIXME???
+  int		doStippling_;	//  Either 0 or 1.
+  Pixmap	stipples_[4];	//  Array of Stipple masks.
 
-  void preinit( int argc, char *argv[] );
   void init( int argc, char *argv[] );
   void getGeometry( void );
-  void parseArgs( int argc, char *argv[] );
-  void getResources( void );
-  void changeResource( const char *name, char *value );
-  void addResource( Parm *parm );
+  void setDisplayName (const char* new_display_name) { strcpy (display_name_, new_display_name); }
+  const char* displayName () { return display_name_; }
+
   void addEvent( Event *event );
   void setColors( void );
   void openDisplay( void );
@@ -167,7 +157,7 @@ protected:
   void mappingNotify( XEvent &event )
     { XRefreshKeyboardMapping( &event.xmapping ); }
   void deleteEvent( XEvent &event );
-  void usage( void );
+  //void usage( void );
   Colormap colormap( void ) { return colormap_; }
   int screen( void ) { return DefaultScreen( display_ ); }
 private:
